Functions to combining respeciate data sets.
rsp_lbind binds two or more respeciate-like
objects. The default option is to stack the supplied data sets (e.g.
respeciate, data.frame, etc) like rbindlist
in data.table (or row_bind in dplyr). This matches columns by name
before stacking the supplied data sets.
rsp_lbind(...)(various) This function is intended to be quite flexible. All
supplied arguments are tested and handled as follows: respeciate-like
objects are passed to data.table::rbindlist as a list to rbind using
data.table methods; Any other arguments that are valid
rbindlist arguments are passed on 'as is'; And, anything else is
(hopefully) ignored.
rsp_lbind attempts to return a single stacked version of the
supplied data sets. If it is successful, the (stacked) data set is typically
returned as a respeciate object or a data.frame with a warning
if it is missing columns respeciate expects.
Dowle M, Srinivasan A (2023). data.table: Extension of `data.frame`. R package version 1.14.8, https://CRAN.R-project.org/package=data.table.